@@ -1,285 +1,311 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="pt_BR">
 <context>
     <name>MXDateTime</name>
     <message>
-        <location filename="datetime.ui" line="20"/>
-        <location filename="datetime.cpp" line="596"/>
+        <location filename="../datetime.ui" line="20"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>MX Date &amp; Time</source>
         <translation>Data &amp; Hora do MX</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="26"/>
+        <location filename="../datetime.ui" line="26"/>
         <source>Close</source>
         <translation>Fechar</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="40"/>
+        <location filename="../datetime.ui" line="40"/>
         <source>Help</source>
         <translation>Ajuda</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="73"/>
+        <location filename="../datetime.ui" line="73"/>
         <source>Apply</source>
         <translation>Aplicar</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="100"/>
+        <location filename="../datetime.ui" line="100"/>
         <source>About...</source>
         <translation>Sobre...</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="124"/>
+        <location filename="../datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
-        <translation>Data &amp;&amp; Hora</translation>
+        <translation>Data e Hora</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="192"/>
+        <location filename="../datetime.ui" line="192"/>
         <source>H:mm:ss</source>
         <translation>H:mm:ss</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="278"/>
-        <location filename="datetime.cpp" line="296"/>
-        <location filename="datetime.cpp" line="303"/>
+        <location filename="../datetime.ui" line="278"/>
+        <location filename="../datetime.cpp" line="298"/>
+        <location filename="../datetime.cpp" line="305"/>
         <source>Hardware Clock</source>
         <translation>Relógio do Equipamento</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="284"/>
+        <location filename="../datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
         <translation>Ferramentas do Relógio do Equipamento</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="290"/>
+        <location filename="../datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
         <translation>Obter informações do Relógio do Equipamento e apresentá-las na caixa abaixo.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="293"/>
+        <location filename="../datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
         <translation>Ler o Relógio do Equipamento</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="300"/>
+        <location filename="../datetime.ui" line="303"/>
         <source>Apply systematic drift corrections to the Hardware Clock.</source>
         <translation>Aplicar as correções ao desvio sistemático do Relógio do Equipamento.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="303"/>
+        <location filename="../datetime.ui" line="306"/>
         <source>Drift Adjust</source>
         <translation>Corrigir o Desvio</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="323"/>
+        <location filename="../datetime.ui" line="329"/>
         <source>Time transfer</source>
         <translation>Transferência horária</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="329"/>
+        <location filename="../datetime.ui" line="335"/>
         <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
         <translation>Configurar imediatamente o Relógio do Sistema para apresentar a hora do Relógio do Equipamento.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="332"/>
+        <location filename="../datetime.ui" line="338"/>
         <source>Hardware Clock to System Clock</source>
         <translation>Do Relógio do Equipamento para o Relógio do Sistema</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="339"/>
+        <location filename="../datetime.ui" line="348"/>
         <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
         <translation>Configurar imediatamente o Relógio do Equipamento para apresentar a hora do Relógio do Sistema.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="342"/>
+        <location filename="../datetime.ui" line="351"/>
         <source>System Clock to Hardware Clock</source>
         <translation>Do Relógio do Sistema para o Relógio do Equipamento</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="349"/>
+        <location filename="../datetime.ui" line="361"/>
         <source>Update the drift factor for the Hardware Clock when it is being set.</source>
         <translation>Atualizar o fator de desvio do Relógio do Equipamento ao configurar.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="352"/>
+        <location filename="../datetime.ui" line="364"/>
         <source>Update the drift</source>
         <translation>Atualizar o desvio</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="362"/>
+        <location filename="../datetime.ui" line="374"/>
         <source>Time zone for the Hardware Clock</source>
         <translation>Fuso horário para o Relógio do Equipamento</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="368"/>
+        <location filename="../datetime.ui" line="380"/>
         <source>Local time</source>
         <translation>Hora local</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="371"/>
+        <location filename="../datetime.ui" line="383"/>
         <source>Local</source>
         <translation>Local</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="378"/>
+        <location filename="../datetime.ui" line="390"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
         <translation>Tempo Universal Coordenado (ou Hora do Meridiano de Greenwich)</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="381"/>
+        <location filename="../datetime.ui" line="393"/>
         <source>UTC</source>
         <translation>UTC</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="421"/>
+        <location filename="../datetime.ui" line="433"/>
         <source>Network Time</source>
         <translation>Hora da Rede</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="427"/>
+        <location filename="../datetime.ui" line="439"/>
         <source>Move the selected item down</source>
         <translation>Mover o item selecionado para baixo</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="438"/>
+        <location filename="../datetime.ui" line="450"/>
         <source>Move the selected item up</source>
         <translation>Mover o item selecionado para cima</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="449"/>
+        <location filename="../datetime.ui" line="461"/>
         <source>Remove the current item from the list</source>
         <translation>Remover da lista o item atual</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="460"/>
+        <location filename="../datetime.ui" line="472"/>
         <source>Add an item to the list</source>
         <translation>Adicionar um item à lista</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="486"/>
+        <location filename="../datetime.ui" line="498"/>
         <source>Automatically update the System Clock with NTP servers:</source>
         <translation>Atualização automática da Hora do Sistema através de servidores NTP:</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="493"/>
+        <location filename="../datetime.ui" line="505"/>
         <source>Immediately update the system clock with NTP servers.</source>
         <translation>Atualização imediata do Relógio do Sistema com os servidores NTP.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="496"/>
+        <location filename="../datetime.ui" line="508"/>
         <source>Update Now</source>
         <translation>Atualizar Agora</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="505"/>
+        <location filename="../datetime.ui" line="520"/>
         <source>List of NTP servers to use.</source>
         <translation>Lista de servidores NTP a serem utilizados.</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="521"/>
+        <location filename="../datetime.ui" line="536"/>
         <source>Type</source>
         <translation>Tipo</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="526"/>
+        <location filename="../datetime.ui" line="541"/>
         <source>Address</source>
         <translation>Endereço</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="531"/>
+        <location filename="../datetime.ui" line="546"/>
         <source>Options</source>
         <translation>Opções</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="270"/>
+        <location filename="../datetime.cpp" line="272"/>
         <source>Reading...</source>
         <translation>Lendo...</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="284"/>
+        <location filename="../datetime.cpp" line="286"/>
         <source>Adjusting...</source>
         <translation>Adjustando...</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="296"/>
-        <location filename="datetime.cpp" line="303"/>
+        <location filename="../datetime.cpp" line="298"/>
+        <location filename="../datetime.cpp" line="305"/>
         <source>System Clock</source>
         <translation>Relógio do Sistema</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="309"/>
+        <location filename="../datetime.cpp" line="311"/>
         <source>The %1 time was transferred to the %2.</source>
         <translation>A hora do %1 foi transferida para o %2.</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="312"/>
+        <location filename="../datetime.cpp" line="314"/>
         <source>The %1 time could not be transferred to the %2.</source>
         <translation>Não foi possível transferir a hora do %1 para o %2.</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="350"/>
+        <location filename="../datetime.cpp" line="354"/>
         <source>Updating...</source>
         <translation>Atualizando...</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="360"/>
+        <location filename="../datetime.cpp" line="367"/>
         <source>The system clock was updated successfully.</source>
         <translation>O relógio do sistema foi atualizado com sucesso.</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="362"/>
+        <location filename="../datetime.cpp" line="369"/>
         <source>The system clock could not be updated.</source>
         <translation>Não foi possível atualizar o relógio do sistema</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="364"/>
+        <location filename="../datetime.cpp" line="371"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
         <translation>Nenhum dos servidores NTP da lista está ativado no momento.</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="595"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>About MX Date &amp; Time</source>
         <translation>Sobre o Data &amp; Hora do MX</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="596"/>
+        <location filename="../datetime.cpp" line="605"/>
         <source>Version: </source>
         <translation>Versão: </translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="597"/>
+        <location filename="../datetime.cpp" line="606"/>
         <source>GUI program for setting the time and date in MX Linux</source>
         <translation>Programa de interface gráfica GUI para definir a Data e a Hora no MX Linux</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="599"/>
+        <location filename="../datetime.cpp" line="608"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Direitos de Autor (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="600"/>
-        <location filename="datetime.cpp" line="614"/>
+        <location filename="../datetime.cpp" line="610"/>
+        <source>%1 License</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>License</source>
-        <translation>Licença</translation>
+        <translation type="vanished">Licença</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="601"/>
         <source>Changelog</source>
-        <translation>Relatório de alterações</translation>
+        <translation type="vanished">Relatório de alterações</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="602"/>
         <source>Cancel</source>
-        <translation>Cancelar</translation>
+        <translation type="vanished">Cancelar</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="628"/>
         <source>&amp;Close</source>
-        <translation>&amp;Fechar</translation>
+        <translation type="vanished">&amp;Fechar</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="646"/>
+        <location filename="../datetime.cpp" line="616"/>
         <source>MX Date &amp; Time Help</source>
         <translation>Ajuda do Data &amp; Hora do MX</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../about.cpp" line="52"/>
+        <source>License</source>
+        <translation type="unfinished">Licença</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="53"/>
+        <location filename="../about.cpp" line="62"/>
+        <source>Changelog</source>
+        <translation type="unfinished">Relatório de alterações</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="54"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="74"/>
+        <source>&amp;Close</source>
+        <translation type="unfinished">&amp;Fechar</translation>
+    </message>
+</context>
+</TS>
